@@ -6,15 +6,17 @@ use vars qw($VERSION);
 
 use base 'Date::Holidays::Adapter';
 
-$VERSION = '1.31';
+$VERSION = '1.32';
 
 sub holidays {
     my ($self, %params) = @_;
 
     my $sub = $self->{_adaptee}->can('holidays');
 
+    my $year = delete $params{year};
+
     if ($sub) {
-        return &{$sub}($params{'year'});
+        return &{$sub}($year, %params);
     } else {
         return {};
     }
@@ -27,8 +29,12 @@ sub is_holiday {
 
     my $holiday;
 
+    my $year = delete $params{year};
+    my $month = delete $params{month};
+    my $day = delete $params{day};
+
     if ($sub) {
-        $holiday = &{$sub}($params{'year'}, $params{'month'}, $params{'day'});
+        $holiday = &{$sub}($year, $month, $day, %params);
     } else {
         $holiday = '';
     }
@@ -50,7 +56,7 @@ Date::Holidays::Adapter::AW - an adapter class for Date::Holidays::AW
 
 =head1 VERSION
 
-This POD describes version 1.31 of Date::Holidays::Adapter::AW
+This POD describes version 1.32 of Date::Holidays::Adapter::AW
 
 =head1 DESCRIPTION
 
